==> java-1.2.3.tar.gz: java-1.2.3/dk.gov.oiosi.library/test/src/dk/gov/oiosi/test/client/TestHttp_SpawnAxisTestServer.java <==
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 *
 * Contributor(s):
 *   Tommy Dejbjerg Pedersen, Lenio
 *   Hans Guldager Knudsen, Lenio
 *   Patrik Johansson, Accenture
 *   Dennis Sgaard, Accenture
 *   Martin Bentzen, Accenture
 *   Jesper Jensen, Avanade
 *   Ramzi Fadel, Avanade
 *   Christian Pedersen, Accenture
 *   Morten Hougesen, Accenture
 *   Mikkel Hippe Brun, ITST
 *   Finn Hartmann Jordal, ITST
 *   Christian Lanng, ITST
 *
 */
/**
 * 
 */
package dk.gov.oiosi.test.client;

import java.io.File;

import org.apache.axis2.AxisFault;
import org.apache.axis2.context.ConfigurationContext;
import org.apache.axis2.context.ConfigurationContextFactory;
import org.apache.axis2.transport.http.SimpleHTTPServer;

import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.test.TestConstants;

/**
 * Spawn Axis test server ant run tests.
 */
public class TestHttp_SpawnAxisTestServer extends AbstractTestRaspStackInterop {

    static {
        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_TEST_RASPCONFIGURATION);
    }

    private static int count = 0;

    private static boolean running = false;

    private static SimpleHTTPServer receiver;

    public static final int TESTING_PORT = 18080;

    public static final String FAILURE_MESSAGE = "Intentional Failure";

    // HOST
    private static String RASP_HOST = "http://localhost:" + TESTING_PORT + "/oiosirasp/services/";

    public String getEndpointUrl(String service) {
        return RASP_HOST + service;
    }

    /*
     * (non-Javadoc)
     * 
     * @see dk.gov.oiosi.test.client.AbstractTestRaspStackInterop#getProxy()
     */
    protected int getProxy() {
        return 0;
    }

    // jUnit

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        if (!running) {
            running = true;
            start();
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
        // Thread.sleep(5000);
        // stop();
    }

    public void localCleanup() throws Exception {
        Thread.sleep(5000);
        stop();
    }

    /**
     * Startup Axis Service.
     * 
     * @param repository
     *            repository
     * @param axis2xml
     *            axis configuration
     * @throws Exception
     */
    public static synchronized void start() throws Exception {
        if (count == 0) {
        	
            ConfigurationContext er = getNewConfigurationContext(ConfigurationHandler.getInstance().getSendPolicy().getAxisRepositoryDir(), ConfigurationHandler.getInstance().getSendPolicy().getAxisConfigurationFile());

            receiver = new SimpleHTTPServer(er, TESTING_PORT);

            try {
                receiver.start();
                System.out.print("Server started on port " + TESTING_PORT + ".....");
            } catch (Exception e) {
                throw new AxisFault(e.getMessage(), e);
            }

            try {
                Thread.sleep(2000);
            } catch (InterruptedException e1) {
                throw new AxisFault("Thread interuptted", e1);
            }

        } else {
            System.out.println("DONOT START SERVER ??? " + count);
        }
        count++;
    }

    /**
     * Initialize axis configuration.
     * 
     * @param repository
     *            repository
     * @param axis2xml
     *            axis configuration
     * @return axis configuration
     * @throws Exception
     */
    public static ConfigurationContext getNewConfigurationContext(String repository, String axis2xml) throws Exception {
        File file = new File(repository);
        if (!file.exists()) {
            throw new Exception("repository directory " + file.getAbsolutePath() + " does not exists");
        }
        System.out.println("REPO : " + new File(repository).getAbsolutePath());
        System.out.println("REPO : " + new File(axis2xml).getAbsolutePath());
        return ConfigurationContextFactory.createConfigurationContextFromFileSystem(file.getAbsolutePath(), axis2xml);
    }

    /**
     * Stop axis service.
     * 
     * @throws AxisFault
     */
    public static synchronized void stop() throws AxisFault {
        if (count == 1) {
            receiver.stop();
            while (receiver.isRunning()) {
                try {
                    Thread.sleep(1000);
                } catch (InterruptedException e1) {
                    // nothing to do here
                }
            }
            count = 0;
            // tp.doStop();
            System.out.print("Server stopped ....." + count);
        } else {
            System.out.print("??? stop called ....." + count + " -> " + (count - 1));

            count--;
        }
        receiver.getConfigurationContext().terminate();
    }

    //

    /*
     * (non-Javadoc)
     * 
     * @see dk.gov.oiosi.test.client.AbstractTestRaspStackInterop#getDefaultServerKeylabel()
     */
    protected String getDefaultServerKeylabel() {
        return "server";
    }

}

==> java-2.0.0.tar.gz: java-2.0.0/dk.gov.oiosi.library/test/src/dk/gov/oiosi/test/client/TestHttp_SpawnAxisTestServer.java <==
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.test.client;

import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.test.TestConstants;
import org.apache.axis2.AxisFault;
import org.apache.axis2.context.ConfigurationContext;
import org.apache.axis2.context.ConfigurationContextFactory;
import org.apache.axis2.transport.http.SimpleHTTPServer;

import java.io.File;

/**
 * Spawn Axis test server ant run tests.
 */
public class TestHttp_SpawnAxisTestServer extends AbstractTestRaspStackInterop {

    static {
        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);
    }

    private static int count = 0;

    private static boolean running = false;

    private static SimpleHTTPServer receiver;

    public static final int TESTING_PORT = 18080;

    public static final String FAILURE_MESSAGE = "Intentional Failure";

    // HOST
    private static String RASP_HOST = "http://localhost:" + TESTING_PORT + "/oiosirasp/services/";

    public String getEndpointUrl(String service) {
        return RASP_HOST + service;
    }

    /*
     * (non-Javadoc)
     *
     * @see dk.gov.oiosi.test.client.AbstractTestRaspStackInterop#getProxy()
     */
    protected int getProxy() {
        return 0;
    }

    // jUnit

    /*
     * (non-Javadoc)
     *
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        if (!running) {
            running = true;
            start();
        }
    }

    /*
     * (non-Javadoc)
     *
     * @see junit.framework.TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
        // Thread.sleep(5000);
        // stop();
    }

    public void localCleanup() throws Exception {
        Thread.sleep(5000);
        stop();
    }

    /**
     * Startup Axis Service.
     *
     * @throws Exception
     */
    public static synchronized void start() throws Exception {
        if (count == 0) {

            ConfigurationContext er = getNewConfigurationContext(ConfigurationHandler.getInstance().getSendPolicy().getAxisRepositoryDir(), ConfigurationHandler.getInstance().getSendPolicy().getAxisConfigurationFile());

            receiver = new SimpleHTTPServer(er, TESTING_PORT);

            try {
                receiver.start();
                System.out.print("Server started on port " + TESTING_PORT + ".....");
            } catch (Exception e) {
                throw new AxisFault(e.getMessage(), e);
            }

            try {
                Thread.sleep(2000);
            } catch (InterruptedException e1) {
                throw new AxisFault("Thread interrupted", e1);
            }

        } else {
            System.out.println("DO NOT START SERVER ??? " + count);
        }
        count++;
    }

    /**
     * Initialize axis configuration.
     *
     * @param repository repository
     * @param axis2xml   axis configuration
     * @return axis configuration
     * @throws Exception
     */
    public static ConfigurationContext getNewConfigurationContext(String repository, String axis2xml) throws Exception {
        File file = new File(repository);
        if (!file.exists()) {
            throw new Exception("repository directory " + file.getAbsolutePath() + " does not exists");
        }
        System.out.println("REPO : " + new File(repository).getAbsolutePath());
        System.out.println("REPO : " + new File(axis2xml).getAbsolutePath());
        return ConfigurationContextFactory.createConfigurationContextFromFileSystem(file.getAbsolutePath(), axis2xml);
    }

    /**
     * Stop axis service.
     *
     * @throws AxisFault
     */
    public static synchronized void stop() throws AxisFault {
        if (count == 1) {
            receiver.stop();
            while (receiver.isRunning()) {
                try {
                    Thread.sleep(1000);
                } catch (InterruptedException e1) {
                    // nothing to do here
                }
            }
            count = 0;
            // tp.doStop();
            System.out.print("Server stopped ....." + count);
        } else {
            System.out.print("??? stop called ....." + count + " -> " + (count - 1));

            count--;
        }
        receiver.getConfigurationContext().terminate();
    }

    //

    /*
     * (non-Javadoc)
     *
     * @see dk.gov.oiosi.test.client.AbstractTestRaspStackInterop#getDefaultServerKeylabel()
     */
    protected String getDefaultServerKeylabel() {
        return "server";
    }
}
